Skip to contents

A character vector of the descriptions used in the redcap_log_event table to describe the different ways a REDCap Project can be created

Usage

project_creation_descriptions

Format

A character vector with 7 elements

Details

DETAILS