A character vector of the descriptions used in the redcap_log_event table to describe the different ways a REDCap Project can be created
A character vector of the descriptions used in the redcap_log_event table to describe the different ways a REDCap Project can be created